==> order-center-domain-3.1.0-CLOUD-DEV-20230625.084845-58-sources.jar: com/tydic/dyc/oc/model/audit/sub/UocAuditOrder.java <==
package com.tydic.dyc.oc.model.audit.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocAuditOrderQueryBo
 * 说明:
 * 时间:2022/3/10 17:17
 * 作者:田桂银
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocAuditOrder implements Serializable {
    private static final long serialVersionUID = -2563420715114348906L;

    @DocField(value = "审批单id")
    private Long auditOrderId;

    @DocField(value = "订单ID")
    private Long orderId;

    @DocField(value = "审批单状态")
    private String auditOrderStatus;

    @DocField(value = "业务编码")
    private String busiCode;

    @DocField(value = "备注")
    private String remark;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建时间 开始")
    private Date createTimeStart;

    @DocField(value = "创建时间 结束")
    private Date createTimeEnd;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "创建人名称")
    private String createOperName;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新时间 开始")
    private Date updateTimeStart;

    @DocField(value = "更新时间 结束")
    private Date updateTimeEnd;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "撤单时间")
    private Date cancelTime;

    @DocField(value = "撤单时间 开始")
    private Date cancelTimeStart;

    @DocField(value = "撤单时间 结束")
    private Date cancelTimeEnd;

    @DocField(value = "撤单工号")
    private String cancelOperId;

    @DocField(value = "撤单原因")
    private String cancelReason;

    @DocField(value = "撤单标志:1 已撤单             0 未撤单")
    private Integer cancelFlag;

    @DocField(value = "竣工时间")
    private Date finishTime;

    @DocField(value = "竣工时间 开始")
    private Date finishTimeStart;

    @DocField(value = "竣工时间 结束")
    private Date finishTimeEnd;

    @DocField(value = "最终审批结果0通过 1驳回")
    private Integer finalResult;

    @DocField(value = "逾期时间")
    private Date expTime;

    @DocField(value = "逾期时间 开始")
    private Date expTimeStart;

    @DocField(value = "逾期时间 结束")
    private Date expTimeEnd;

    @DocField(value = "扩展字段1")
    private String extField1;

    @DocField(value = "扩展字段2")
    private String extField2;

    @DocField(value = "扩展字段3")
    private String extField3;

    @DocField(value = "扩展字段4")
    private String extField4;

    @DocField(value = "扩展字段5")
    private String extField5;

    @DocField(value = "删除标志1已删除")
    private Integer delTag;

    @DocField(value = "排序")
    private String orderBy;
    @DocField(value = "流程实例id")
    private String procInstId;
}

==> order-center-domain-3.2.2-CLOUD-DEV-20240704.113450-12-sources.jar: com/tydic/dyc/oc/model/audit/sub/UocAuditOrder.java <==
package com.tydic.dyc.oc.model.audit.sub;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocAuditOrderQueryBo
 * 说明:
 * 时间:2022/3/10 17:17
 * 作者:田桂银
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocAuditOrder implements Serializable {
    private static final long serialVersionUID = -2563420715114348906L;

    //审批单id//
    private Long auditOrderId;

    //订单ID//
    private Long orderId;

    //审批单状态//
    private String auditOrderStatus;

    //业务编码//
    private String busiCode;

    //备注//
    private String remark;

    //创建时间//
    private Date createTime;

    //创建时间 开始//
    private Date createTimeStart;

    //创建时间 结束//
    private Date createTimeEnd;

    //创建工号//
    private String createOperId;

    //创建人名称//
    private String createOperName;

    //更新时间//
    private Date updateTime;

    //更新时间 开始//
    private Date updateTimeStart;

    //更新时间 结束//
    private Date updateTimeEnd;

    //更新工号//
    private String updateOperId;

    //撤单时间//
    private Date cancelTime;

    //撤单时间 开始//
    private Date cancelTimeStart;

    //撤单时间 结束//
    private Date cancelTimeEnd;

    //撤单工号//
    private String cancelOperId;

    //撤单原因//
    private String cancelReason;

    //撤单标志:1 已撤单             0 未撤单//
    private Integer cancelFlag;

    //竣工时间//
    private Date finishTime;

    //竣工时间 开始//
    private Date finishTimeStart;

    //竣工时间 结束//
    private Date finishTimeEnd;

    //最终审批结果0通过 1驳回//
    private Integer finalResult;

    //逾期时间//
    private Date expTime;

    //逾期时间 开始//
    private Date expTimeStart;

    //逾期时间 结束//
    private Date expTimeEnd;

    //扩展字段1//
    private String extField1;

    //扩展字段2//
    private String extField2;

    //扩展字段3//
    private String extField3;

    //扩展字段4//
    private String extField4;

    //扩展字段5//
    private String extField5;

    //删除标志1已删除//
    private Integer delTag;

    //排序//
    private String orderBy;
    //流程实例id//
    private String procInstId;
}
